##############
SampleSize Lib
##############

|test| |codecov| |docs| |readthedocs| |pypi| 

.. |test| image:: https://github.com/andriygav/SampleSizeLib/workflows/test/badge.svg
    :target: https://github.com/andriygav/SampleSizeLib/tree/master
    :alt: Test status
    
.. |codecov| image:: https://img.shields.io/codecov/c/github/andriygav/samplesizelib/master
    :target: https://github.com/andriygav/SampleSizeLib/tree/master
    :alt: Test coverage

.. |docs| image:: https://github.com/andriygav/SampleSizeLib/workflows/docs/badge.svg
    :target: https://andriygav.github.io/SampleSizeLib/
    :alt: Build status

.. |readthedocs| image:: https://img.shields.io/readthedocs/samplesizelib/stable?label=readthedocs
    :target: https://samplesizelib.readthedocs.io/en/stable/
    :alt: ReadTheDocs
    
.. |pypi| image:: https://img.shields.io/pypi/v/SampleSizeLib
    :target: https://pypi.org/project/SampleSizeLib/
    :alt: PyPI

Basic information
=================

Implementation code for a sample size estimation task. The `source code <https://github.com/andriygav/SampleSizeLib/tree/master/src>`_ for the problem of the sample size estimation for linear models.


All information about this project can be found in the `documentation <https://andriygav.github.io/SampleSizeLib/>`_.

Requirements and Installation
=============================
A simple instruction of installation using pip is provided near the `source code <https://github.com/andriygav/SampleSizeLib/tree/master/src>`_.

More information about installation can be found in documentation `installation <https://andriygav.github.io/SampleSizeLib/installation.html>`_ page.

Example of use
==============
A simple examples of module usage can be found in documentation `example <https://andriygav.github.io/SampleSizeLib/example.html>`_ page.
